@@ -171,7 +171,7 @@ class Player:
                             + [x.sources for x in self.discord.usernames]
                             + [self.fc_information.get_sources_flat()]
                             + [self.teams_information.get_sources_flat()]
-                            + [[self.pronoun.source]], [])
+                            + [[self.pronoun.source] if self.pronoun else []], [])
                     ),
                     reverse=True
                 )
